You are viewing a plain text version of this content. The canonical link for it is here.
Posted to scm@geronimo.apache.org by dj...@apache.org on 2011/05/02 23:49:46 UTC

svn commit: r1098803 [2/3] - in /geronimo/server/branches/3.0-osgi: ./ plugins/ plugins/j2ee/geronimo-security-builder/src/main/java/org/apache/geronimo/security/deployment/model/jaspi/ plugins/j2ee/geronimo-web-2.5-builder/src/main/java/org/apache/ger...

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType.java
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType2.java
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType2.java?rev=1098803&view=auto
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType2.java (added)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType2.java Mon May  2 21:49:44 2011
@@ -0,0 +1,37 @@
+//
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.1-2 
+// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
+// Any modifications to this file will be lost upon recompilation of the source schema. 
+// Generated on: 2011.04.29 at 10:50:34 AM PDT 
+//
+
+
+package org.apache.geronimo.tomcat.deployment.model;
+
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlType;
+
+
+/**
+ * <p>Java class for emptyType2 complex type.
+ * 
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ * 
+ * <pre>
+ * &lt;complexType name="emptyType2">
+ *   &lt;complexContent>
+ *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ *     &lt;/restriction>
+ *   &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ * 
+ * 
+ */
+@XmlAccessorType(XmlAccessType.FIELD)
+@XmlType(name = "emptyType2", namespace = "http://geronimo.apache.org/xml/ns/web/tomcat/config-1.0")
+public class EmptyType2 {
+
+
+}

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType2.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType2.java
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/EmptyType2.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/JaxbUtil.java
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/JaxbUtil.java?rev=1098803&view=auto
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/JaxbUtil.java (added)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/JaxbUtil.java Mon May  2 21:49:44 2011
@@ -0,0 +1,195 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+
+package org.apache.geronimo.tomcat.deployment.model;
+
+import java.io.ByteArrayInputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.Reader;
+import java.io.Writer;
+
+import javax.xml.bind.JAXBContext;
+import javax.xml.bind.JAXBElement;
+import javax.xml.bind.JAXBException;
+import javax.xml.bind.Marshaller;
+import javax.xml.bind.Unmarshaller;
+import javax.xml.bind.ValidationEvent;
+import javax.xml.bind.ValidationEventHandler;
+import javax.xml.parsers.ParserConfigurationException;
+import javax.xml.parsers.SAXParser;
+import javax.xml.parsers.SAXParserFactory;
+import javax.xml.stream.XMLInputFactory;
+import javax.xml.stream.XMLStreamException;
+import javax.xml.stream.XMLStreamReader;
+import javax.xml.transform.sax.SAXSource;
+import org.apache.geronimo.deployment.service.plan.JavabeanType;
+import org.apache.geronimo.deployment.service.plan.ModuleType;
+import org.apache.geronimo.web25.deployment.model.WebAppType;
+import org.apache.openejb.jee.wls.WeblogicEnterpriseBean;
+import org.xml.sax.Attributes;
+import org.xml.sax.InputSource;
+import org.xml.sax.SAXException;
+import org.xml.sax.XMLFilter;
+import org.xml.sax.XMLReader;
+import org.xml.sax.helpers.XMLFilterImpl;
+
+/**
+ * @version $Rev:$ $Date:$
+ */
+public class JaxbUtil {
+
+    public static final XMLInputFactory XMLINPUT_FACTORY = XMLInputFactory.newInstance();
+    private static  JAXBContext TOMCAT_WEB_APP_CONTEXT;
+    private static  JAXBContext WEB_APP_CONTEXT;
+    static {
+        try {
+            TOMCAT_WEB_APP_CONTEXT = JAXBContext.newInstance(TomcatWebAppType.class);
+        } catch (Throwable e) {
+            e.printStackTrace();
+//            throw new RuntimeException(e);
+        }
+        try {
+            WEB_APP_CONTEXT = JAXBContext.newInstance(WebAppType.class);
+        } catch (Throwable e) {
+            e.printStackTrace();
+//            throw new RuntimeException(e);
+        }
+    }
+
+    public static WebAppType unmarshalTomcatWebApp(InputStream in, boolean validate) throws XMLStreamException, JAXBException {
+        XMLStreamReader xmlStream = XMLINPUT_FACTORY.createXMLStreamReader(in);
+        Unmarshaller unmarshaller = TOMCAT_WEB_APP_CONTEXT.createUnmarshaller();
+        JAXBElement<TomcatWebAppType> element = unmarshaller.unmarshal(xmlStream, TomcatWebAppType.class);
+        WebAppType moduleType = element.getValue();
+        return moduleType;
+    }
+
+    public static WebAppType unmarshalWebApp(InputStream in, boolean validate) throws XMLStreamException, JAXBException {
+        XMLStreamReader xmlStream = XMLINPUT_FACTORY.createXMLStreamReader(in);
+        Unmarshaller unmarshaller = WEB_APP_CONTEXT.createUnmarshaller();
+        JAXBElement<WebAppType> element = unmarshaller.unmarshal(xmlStream, WebAppType.class);
+        WebAppType moduleType = element.getValue();
+        return moduleType;
+    }
+
+    public static void marshalTomcatWebApp(TomcatWebAppType object, Writer out) throws JAXBException {
+        Marshaller marshaller = TOMCAT_WEB_APP_CONTEXT.createMarshaller();
+
+        marshaller.setProperty("jaxb.formatted.output", true);
+
+        marshaller.marshal(object, out);
+    }
+    public static <T> void marshal(Class<T> type, Object object, Writer out) throws JAXBException {
+        JAXBContext ctx2 = JAXBContext.newInstance(type);
+        Marshaller marshaller = ctx2.createMarshaller();
+
+        marshaller.setProperty("jaxb.formatted.output", true);
+
+        marshaller.marshal(object, out);
+    }
+
+
+    public static WebAppType unmarshalModule2(InputStream in, boolean validate) throws ParserConfigurationException, SAXException, JAXBException {
+        InputSource inputSource = new InputSource(in);
+
+        SAXParserFactory factory = SAXParserFactory.newInstance();
+        factory.setNamespaceAware(true);
+        factory.setValidating(validate);
+        SAXParser parser = factory.newSAXParser();
+
+        Unmarshaller unmarshaller = TOMCAT_WEB_APP_CONTEXT.createUnmarshaller();
+        unmarshaller.setEventHandler(new ValidationEventHandler() {
+            public boolean handleEvent(ValidationEvent validationEvent) {
+                System.out.println(validationEvent);
+                return false;
+            }
+        });
+
+        XMLFilter xmlFilter = new NoSourceFilter(parser.getXMLReader());
+        xmlFilter.setContentHandler(unmarshaller.getUnmarshallerHandler());
+
+        SAXSource source = new SAXSource(xmlFilter, inputSource);
+
+        return WebAppType.class.cast(unmarshaller.unmarshal(source));
+    }
+
+    /**
+     * Read in a T from the input stream.
+     *
+     * @param type     Class of object to be read in
+     * @param in       input stream to read
+     * @param validate whether to validate the input.
+     * @param <T>      class of object to be returned
+     * @return a T read from the input stream
+     * @throws javax.xml.parsers.ParserConfigurationException is the SAX parser can not be configured
+     * @throws org.xml.sax.SAXException                 if there is an xml problem
+     * @throws JAXBException                if the xml cannot be marshalled into a T.
+     */
+    public static <T> T unmarshal(Class<T> type, InputStream in, boolean validate) throws ParserConfigurationException, SAXException, JAXBException {
+        InputSource inputSource = new InputSource(in);
+
+        SAXParserFactory factory = SAXParserFactory.newInstance();
+        factory.setNamespaceAware(true);
+        factory.setValidating(validate);
+        SAXParser parser = factory.newSAXParser();
+
+        JAXBContext ctx = JAXBContext.newInstance(type);
+        Unmarshaller unmarshaller = ctx.createUnmarshaller();
+        unmarshaller.setEventHandler(new ValidationEventHandler() {
+            public boolean handleEvent(ValidationEvent validationEvent) {
+                System.out.println(validationEvent);
+                return false;
+            }
+        });
+
+        XMLFilter xmlFilter = new NoSourceFilter(parser.getXMLReader());
+        xmlFilter.setContentHandler(unmarshaller.getUnmarshallerHandler());
+
+        SAXSource source = new SAXSource(xmlFilter, inputSource);
+
+        return type.cast(unmarshaller.unmarshal(source));
+    }
+
+    public static class NoSourceFilter extends XMLFilterImpl {
+        private static final InputSource EMPTY_INPUT_SOURCE = new InputSource(new ByteArrayInputStream(new byte[0]));
+
+        public NoSourceFilter(XMLReader xmlReader) {
+            super(xmlReader);
+        }
+
+        @Override
+        public InputSource resolveEntity(String publicId, String systemId) throws SAXException, IOException {
+            return EMPTY_INPUT_SOURCE;
+        }
+
+        @Override
+        public void startElement(String uri, String localName, String qname, Attributes atts) throws SAXException {
+            super.startElement("http://geronimo.apache.org/xml/ns/deployment-1.2", localName, qname, atts);
+        }
+
+        @Override
+        public void endElement(String uri, String localName, String qName) throws SAXException {
+            super.endElement("http://geronimo.apache.org/xml/ns/deployment-1.2", localName, qName);
+        }
+    }
+
+
+}

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/JaxbUtil.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/JaxbUtil.java
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/JaxbUtil.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/ParameterType.java
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/ParameterType.java?rev=1098803&view=auto
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/ParameterType.java (added)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/ParameterType.java Mon May  2 21:49:44 2011
@@ -0,0 +1,123 @@
+//
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.1-2 
+// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
+// Any modifications to this file will be lost upon recompilation of the source schema. 
+// Generated on: 2011.04.29 at 10:50:34 AM PDT 
+//
+
+
+package org.apache.geronimo.tomcat.deployment.model;
+
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlAttribute;
+import javax.xml.bind.annotation.XmlType;
+
+
+/**
+ * <p>Java class for parameterType complex type.
+ * 
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ * 
+ * <pre>
+ * &lt;complexType name="parameterType">
+ *   &lt;complexContent>
+ *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *       &lt;attribute name="value" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *       &lt;attribute name="override" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
+ *     &lt;/restriction>
+ *   &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ * 
+ * 
+ */
+@XmlAccessorType(XmlAccessType.FIELD)
+@XmlType(name = "parameterType")
+public class ParameterType {
+
+    @XmlAttribute(name = "name")
+    protected String name;
+    @XmlAttribute(name = "value")
+    protected String value;
+    @XmlAttribute(name = "override")
+    protected Boolean override;
+
+    /**
+     * Gets the value of the name property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getName() {
+        return name;
+    }
+
+    /**
+     * Sets the value of the name property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setName(String value) {
+        this.name = value;
+    }
+
+    /**
+     * Gets the value of the value property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getValue() {
+        return value;
+    }
+
+    /**
+     * Sets the value of the value property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setValue(String value) {
+        this.value = value;
+    }
+
+    /**
+     * Gets the value of the override property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link Boolean }
+     *     
+     */
+    public boolean isOverride() {
+        if (override == null) {
+            return false;
+        } else {
+            return override;
+        }
+    }
+
+    /**
+     * Sets the value of the override property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link Boolean }
+     *     
+     */
+    public void setOverride(Boolean value) {
+        this.override = value;
+    }
+
+}

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/ParameterType.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/ParameterType.java
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/ParameterType.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatConfigType.java
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatConfigType.java?rev=1098803&view=auto
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatConfigType.java (added)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatConfigType.java Mon May  2 21:49:44 2011
@@ -0,0 +1,289 @@
+//
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.1-2 
+// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
+// Any modifications to this file will be lost upon recompilation of the source schema. 
+// Generated on: 2011.04.29 at 10:50:34 AM PDT 
+//
+
+
+package org.apache.geronimo.tomcat.deployment.model;
+
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlElement;
+import javax.xml.bind.annotation.XmlType;
+import org.apache.geronimo.web25.deployment.model.ContainerConfigType;
+
+
+/**
+ * <p>Java class for tomcat-configType complex type.
+ * 
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ * 
+ * <pre>
+ * &lt;complexType name="tomcat-configType">
+ *   &lt;complexContent>
+ *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ *       &lt;sequence>
+ *         &lt;element name="host" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="cross-context" type="{http://geronimo.apache.org/xml/ns/web/tomcat/config-1.0}emptyType2" minOccurs="0"/>
+ *         &lt;element name="disable-cookies" type="{http://geronimo.apache.org/xml/ns/web/tomcat/config-1.0}emptyType2" minOccurs="0"/>
+ *         &lt;element name="valve-chain" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="listener-chain" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="tomcat-realm" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="manager" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="cluster" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *       &lt;/sequence>
+ *     &lt;/restriction>
+ *   &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ * 
+ * 
+ */
+@XmlAccessorType(XmlAccessType.FIELD)
+@XmlType(name = "tomcat-configType", namespace = "http://geronimo.apache.org/xml/ns/web/tomcat/config-1.0", propOrder = {
+    "host",
+    "crossContext",
+    "disableCookies",
+    "context",
+    "valveChain",
+    "listenerChain",
+    "tomcatRealm",
+    "manager",
+    "cluster"
+})
+public class TomcatConfigType extends ContainerConfigType {
+
+    protected String host;
+    @XmlElement(name = "cross-context")
+    protected EmptyType crossContext;
+    @XmlElement(name = "disable-cookies")
+    protected EmptyType disableCookies;
+    protected ContextType context;
+    @XmlElement(name = "valve-chain")
+    protected String valveChain;
+    @XmlElement(name = "listener-chain")
+    protected String listenerChain;
+    @XmlElement(name = "tomcat-realm")
+    protected String tomcatRealm;
+    protected String manager;
+    protected String cluster;
+
+    /**
+     * Gets the value of the host property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getHost() {
+        return host;
+    }
+
+    /**
+     * Sets the value of the host property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setHost(String value) {
+        this.host = value;
+    }
+
+    /**
+     * Gets the value of the crossContext property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link EmptyType2 }
+     *     
+     */
+    public EmptyType getCrossContext() {
+        return crossContext;
+    }
+
+    /**
+     * Sets the value of the crossContext property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link EmptyType2 }
+     *     
+     */
+    public void setCrossContext(EmptyType value) {
+        this.crossContext = value;
+    }
+
+    /**
+     * Gets the value of the disableCookies property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link EmptyType2 }
+     *     
+     */
+    public EmptyType getDisableCookies() {
+        return disableCookies;
+    }
+
+    /**
+     * Sets the value of the disableCookies property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link EmptyType2 }
+     *     
+     */
+    public void setDisableCookies(EmptyType value) {
+        this.disableCookies = value;
+    }
+
+    /**
+     * Gets the value of the context property.
+     *
+     * @return
+     *     possible object is
+     *     {@link ContextType }
+     *
+     */
+    public ContextType getContext() {
+        return context;
+    }
+
+    /**
+     * Sets the value of the context property.
+     *
+     * @param value
+     *     allowed object is
+     *     {@link ContextType }
+     *
+     */
+    public void setContext(ContextType value) {
+        this.context = value;
+    }
+
+    /**
+     * Gets the value of the valveChain property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getValveChain() {
+        return valveChain;
+    }
+
+    /**
+     * Sets the value of the valveChain property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setValveChain(String value) {
+        this.valveChain = value;
+    }
+
+    /**
+     * Gets the value of the listenerChain property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getListenerChain() {
+        return listenerChain;
+    }
+
+    /**
+     * Sets the value of the listenerChain property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setListenerChain(String value) {
+        this.listenerChain = value;
+    }
+
+    /**
+     * Gets the value of the tomcatRealm property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getTomcatRealm() {
+        return tomcatRealm;
+    }
+
+    /**
+     * Sets the value of the tomcatRealm property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setTomcatRealm(String value) {
+        this.tomcatRealm = value;
+    }
+
+    /**
+     * Gets the value of the manager property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getManager() {
+        return manager;
+    }
+
+    /**
+     * Sets the value of the manager property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setManager(String value) {
+        this.manager = value;
+    }
+
+    /**
+     * Gets the value of the cluster property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getCluster() {
+        return cluster;
+    }
+
+    /**
+     * Sets the value of the cluster property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setCluster(String value) {
+        this.cluster = value;
+    }
+
+}

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatConfigType.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatConfigType.java
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatConfigType.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Copied: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatObjectFactory.java (from r1098802, geronimo/server/branches/3.0-osgi/plugins/j2ee/geronimo-web-2.5-builder/src/main/java/org/apache/geronimo/web25/deployment/model/ObjectFactory.java)
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatObjectFactory.java?p2=geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatObjectFactory.java&p1=geronimo/server/branches/3.0-osgi/plugins/j2ee/geronimo-web-2.5-builder/src/main/java/org/apache/geronimo/web25/deployment/model/ObjectFactory.java&r1=1098802&r2=1098803&rev=1098803&view=diff
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatWebAppType.java (added)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatWebAppType.java Mon May  2 21:49:44 2011
@@ -0,0 +1,829 @@
+//
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.1-2 
+// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
+// Any modifications to this file will be lost upon recompilation of the source schema. 
+// Generated on: 2011.04.29 at 10:50:34 AM PDT 
+//
+
+
+package org.apache.geronimo.tomcat.deployment.model;
+
+import java.util.ArrayList;
+import java.util.List;
+import javax.xml.bind.JAXBElement;
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlAnyElement;
+import javax.xml.bind.annotation.XmlElement;
+import javax.xml.bind.annotation.XmlElementRef;
+import javax.xml.bind.annotation.XmlType;
+import org.apache.geronimo.deployment.service.plan.EnvironmentType;
+import org.apache.geronimo.j2ee.deployment.model.naming.AbstractNamingEntryType;
+import org.apache.geronimo.j2ee.deployment.model.naming.EjbLocalRefType;
+import org.apache.geronimo.j2ee.deployment.model.naming.EjbRefType;
+import org.apache.geronimo.j2ee.deployment.model.naming.EnvEntryType;
+import org.apache.geronimo.j2ee.deployment.model.naming.MessageDestinationType;
+import org.apache.geronimo.j2ee.deployment.model.naming.ResourceEnvRefType;
+import org.apache.geronimo.j2ee.deployment.model.naming.ResourceRefType;
+import org.apache.geronimo.j2ee.deployment.model.naming.ServiceRefType;
+import org.apache.geronimo.security.deployment.model.security.SecurityRefType;
+import org.apache.geronimo.security.deployment.model.security.SecurityType;
+
+
+/**
+ * <p>Java class for web-appType complex type.
+ * 
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ * 
+ * <pre>
+ * &lt;complexType name="web-appType">
+ *   &lt;complexContent>
+ *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ *       &lt;sequence>
+ *         &lt;element ref="{http://geronimo.apache.org/xml/ns/deployment-1.2}environment" minOccurs="0"/>
+ *         &lt;element name="context-root" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="work-dir" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="web-container" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="host" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="cross-context" type="{http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1}emptyType" minOccurs="0"/>
+ *         &lt;element name="disable-cookies" type="{http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1}emptyType" minOccurs="0"/>
+ *         &lt;element name="context" type="{http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1}contextType" minOccurs="0"/>
+ *         &lt;element name="valve-chain" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="listener-chain" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="tomcat-realm" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="manager" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="cluster" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;group ref="{http://geronimo.apache.org/xml/ns/naming-1.2}jndiEnvironmentRefsGroup"/>
+ *         &lt;element ref="{http://geronimo.apache.org/xml/ns/naming-1.2}message-destination" maxOccurs="unbounded" minOccurs="0"/>
+ *         &lt;sequence minOccurs="0">
+ *           &lt;element name="security-realm-name" type="{http://www.w3.org/2001/XMLSchema}string"/>
+ *           &lt;element name="authentication" type="{http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1}authenticationType" minOccurs="0"/>
+ *           &lt;choice minOccurs="0">
+ *             &lt;element ref="{http://geronimo.apache.org/xml/ns/security-2.0}security"/>
+ *             &lt;element ref="{http://geronimo.apache.org/xml/ns/security-2.0}security-ref"/>
+ *           &lt;/choice>
+ *         &lt;/sequence>
+ *         &lt;any namespace='http://java.sun.com/xml/ns/persistence' maxOccurs="unbounded" minOccurs="0"/>
+ *       &lt;/sequence>
+ *     &lt;/restriction>
+ *   &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ * 
+ * 
+ */
+@XmlAccessorType(XmlAccessType.FIELD)
+@XmlType(name = "web-appType", propOrder = {
+    "environment",
+    "contextRoot",
+    "workDir",
+    "webContainer",
+    "host",
+    "crossContext",
+    "disableCookies",
+    "context",
+    "valveChain",
+    "listenerChain",
+    "tomcatRealm",
+    "manager",
+    "cluster",
+    "abstractNamingEntry",
+    "envEntry",
+    "ejbRef",
+    "ejbLocalRef",
+    "serviceRef",
+    "resourceRef",
+    "resourceEnvRef",
+    "messageDestination",
+    "securityRealmName",
+    "authentication",
+    "security",
+    "securityRef",
+    "any"
+})
+public class TomcatWebAppType extends org.apache.geronimo.web25.deployment.model.WebAppType {
+
+    @XmlElement(namespace = "http://geronimo.apache.org/xml/ns/deployment-1.2")
+    protected EnvironmentType environment;
+    @XmlElement(name = "context-root")
+    protected String contextRoot;
+    @XmlElement(name = "work-dir")
+    protected String workDir;
+    @XmlElement(name = "web-container")
+    protected String webContainer;
+    protected String host;
+    @XmlElement(name = "cross-context")
+    protected EmptyType crossContext;
+    @XmlElement(name = "disable-cookies")
+    protected EmptyType disableCookies;
+    protected ContextType context;
+    @XmlElement(name = "valve-chain")
+    protected String valveChain;
+    @XmlElement(name = "listener-chain")
+    protected String listenerChain;
+    @XmlElement(name = "tomcat-realm")
+    protected String tomcatRealm;
+    protected String manager;
+    protected String cluster;
+    @XmlElementRef(name = "abstract-naming-entry", namespace = "http://geronimo.apache.org/xml/ns/naming-1.2", type = JAXBElement.class)
+    protected List<JAXBElement<AbstractNamingEntryType>> abstractNamingEntry;
+    @XmlElement(name = "env-entry", namespace = "http://geronimo.apache.org/xml/ns/naming-1.2")
+    protected List<EnvEntryType> envEntry;
+    @XmlElement(name = "ejb-ref", namespace = "http://geronimo.apache.org/xml/ns/naming-1.2")
+    protected List<EjbRefType> ejbRef;
+    @XmlElement(name = "ejb-local-ref", namespace = "http://geronimo.apache.org/xml/ns/naming-1.2")
+    protected List<EjbLocalRefType> ejbLocalRef;
+    @XmlElement(name = "service-ref", namespace = "http://geronimo.apache.org/xml/ns/naming-1.2")
+    protected List<ServiceRefType> serviceRef;
+    @XmlElement(name = "resource-ref", namespace = "http://geronimo.apache.org/xml/ns/naming-1.2")
+    protected List<ResourceRefType> resourceRef;
+    @XmlElement(name = "resource-env-ref", namespace = "http://geronimo.apache.org/xml/ns/naming-1.2")
+    protected List<ResourceEnvRefType> resourceEnvRef;
+    @XmlElement(name = "message-destination", namespace = "http://geronimo.apache.org/xml/ns/naming-1.2")
+    protected List<MessageDestinationType> messageDestination;
+    @XmlElement(name = "security-realm-name")
+    protected String securityRealmName;
+    protected AuthenticationType authentication;
+    @XmlElement(namespace = "http://geronimo.apache.org/xml/ns/security-2.0")
+    protected SecurityType security;
+    @XmlElement(name = "security-ref", namespace = "http://geronimo.apache.org/xml/ns/security-2.0")
+    protected SecurityRefType securityRef;
+    @XmlAnyElement(lax = true)
+    protected List<Object> any;
+
+    /**
+     * 
+     *                         Reference to environment element defined in imported
+     *                         "geronimo-module-1.2.xsd"
+     *                     
+     * 
+     * @return
+     *     possible object is
+     *     {@link EnvironmentType }
+     *     
+     */
+//    public EnvironmentType getEnvironment() {
+//        return environment;
+//    }
+
+    /**
+     * Sets the value of the environment property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link EnvironmentType }
+     *     
+     */
+//    public void setEnvironment(EnvironmentType value) {
+//        this.environment = value;
+//    }
+
+    /**
+     * Gets the value of the contextRoot property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+//    public String getContextRoot() {
+//        return contextRoot;
+//    }
+
+    /**
+     * Sets the value of the contextRoot property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+//    public void setContextRoot(String value) {
+//        this.contextRoot = value;
+//    }
+
+    /**
+     * Gets the value of the workDir property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+//    public String getWorkDir() {
+//        return workDir;
+//    }
+
+    /**
+     * Sets the value of the workDir property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+//    public void setWorkDir(String value) {
+//        this.workDir = value;
+//    }
+
+    /**
+     * Gets the value of the webContainer property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+//    public String getWebContainer() {
+//        return webContainer;
+//    }
+
+    /**
+     * Sets the value of the webContainer property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+//    public void setWebContainer(String value) {
+//        this.webContainer = value;
+//    }
+
+    /**
+     * Gets the value of the host property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getHost() {
+        return host;
+    }
+
+    /**
+     * Sets the value of the host property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setHost(String value) {
+        this.host = value;
+    }
+
+    /**
+     * Gets the value of the crossContext property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link EmptyType }
+     *     
+     */
+    public EmptyType getCrossContext() {
+        return crossContext;
+    }
+
+    /**
+     * Sets the value of the crossContext property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link EmptyType }
+     *     
+     */
+    public void setCrossContext(EmptyType value) {
+        this.crossContext = value;
+    }
+
+    /**
+     * Gets the value of the disableCookies property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link EmptyType }
+     *     
+     */
+    public EmptyType getDisableCookies() {
+        return disableCookies;
+    }
+
+    /**
+     * Sets the value of the disableCookies property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link EmptyType }
+     *     
+     */
+    public void setDisableCookies(EmptyType value) {
+        this.disableCookies = value;
+    }
+
+    /**
+     * Gets the value of the context property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link ContextType }
+     *     
+     */
+    public ContextType getContext() {
+        return context;
+    }
+
+    /**
+     * Sets the value of the context property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link ContextType }
+     *     
+     */
+    public void setContext(ContextType value) {
+        this.context = value;
+    }
+
+    /**
+     * Gets the value of the valveChain property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getValveChain() {
+        return valveChain;
+    }
+
+    /**
+     * Sets the value of the valveChain property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setValveChain(String value) {
+        this.valveChain = value;
+    }
+
+    /**
+     * Gets the value of the listenerChain property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getListenerChain() {
+        return listenerChain;
+    }
+
+    /**
+     * Sets the value of the listenerChain property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setListenerChain(String value) {
+        this.listenerChain = value;
+    }
+
+    /**
+     * Gets the value of the tomcatRealm property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getTomcatRealm() {
+        return tomcatRealm;
+    }
+
+    /**
+     * Sets the value of the tomcatRealm property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setTomcatRealm(String value) {
+        this.tomcatRealm = value;
+    }
+
+    /**
+     * Gets the value of the manager property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getManager() {
+        return manager;
+    }
+
+    /**
+     * Sets the value of the manager property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setManager(String value) {
+        this.manager = value;
+    }
+
+    /**
+     * Gets the value of the cluster property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getCluster() {
+        return cluster;
+    }
+
+    /**
+     * Sets the value of the cluster property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setCluster(String value) {
+        this.cluster = value;
+    }
+
+    /**
+     * Gets the value of the abstractNamingEntry property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the abstractNamingEntry property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getAbstractNamingEntry().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link JAXBElement }{@code <}{@link AbstractNamingEntryType }{@code >}
+     * 
+     * 
+     */
+//    public List<JAXBElement<AbstractNamingEntryType>> getAbstractNamingEntry() {
+//        if (abstractNamingEntry == null) {
+//            abstractNamingEntry = new ArrayList<JAXBElement<AbstractNamingEntryType>>();
+//        }
+//        return this.abstractNamingEntry;
+//    }
+
+    /**
+     * Gets the value of the envEntry property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the envEntry property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getEnvEntry().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link EnvEntryType }
+     * 
+     * 
+     */
+//    public List<EnvEntryType> getEnvEntry() {
+//        if (envEntry == null) {
+//            envEntry = new ArrayList<EnvEntryType>();
+//        }
+//        return this.envEntry;
+//    }
+
+    /**
+     * Gets the value of the ejbRef property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the ejbRef property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getEjbRef().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link EjbRefType }
+     * 
+     * 
+     */
+//    public List<EjbRefType> getEjbRef() {
+//        if (ejbRef == null) {
+//            ejbRef = new ArrayList<EjbRefType>();
+//        }
+//        return this.ejbRef;
+//    }
+
+    /**
+     * Gets the value of the ejbLocalRef property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the ejbLocalRef property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getEjbLocalRef().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link EjbLocalRefType }
+     * 
+     * 
+     */
+//    public List<EjbLocalRefType> getEjbLocalRef() {
+//        if (ejbLocalRef == null) {
+//            ejbLocalRef = new ArrayList<EjbLocalRefType>();
+//        }
+//        return this.ejbLocalRef;
+//    }
+
+    /**
+     * Gets the value of the serviceRef property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the serviceRef property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getServiceRef().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link ServiceRefType }
+     * 
+     * 
+     */
+//    public List<ServiceRefType> getServiceRef() {
+//        if (serviceRef == null) {
+//            serviceRef = new ArrayList<ServiceRefType>();
+//        }
+//        return this.serviceRef;
+//    }
+
+    /**
+     * Gets the value of the resourceRef property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the resourceRef property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getResourceRef().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link ResourceRefType }
+     * 
+     * 
+     */
+//    public List<ResourceRefType> getResourceRef() {
+//        if (resourceRef == null) {
+//            resourceRef = new ArrayList<ResourceRefType>();
+//        }
+//        return this.resourceRef;
+//    }
+
+    /**
+     * Gets the value of the resourceEnvRef property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the resourceEnvRef property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getResourceEnvRef().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link ResourceEnvRefType }
+     * 
+     * 
+     */
+//    public List<ResourceEnvRefType> getResourceEnvRef() {
+//        if (resourceEnvRef == null) {
+//            resourceEnvRef = new ArrayList<ResourceEnvRefType>();
+//        }
+//        return this.resourceEnvRef;
+//    }
+
+    /**
+     * 
+     *                         Reference to message-destination element defined in
+     *                         imported "geronimo-naming-1.2.xsd"
+     *                     Gets the value of the messageDestination property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the messageDestination property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getMessageDestination().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link MessageDestinationType }
+     * 
+     * 
+     */
+//    public List<MessageDestinationType> getMessageDestination() {
+//        if (messageDestination == null) {
+//            messageDestination = new ArrayList<MessageDestinationType>();
+//        }
+//        return this.messageDestination;
+//    }
+
+    /**
+     * Gets the value of the securityRealmName property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+//    public String getSecurityRealmName() {
+//        return securityRealmName;
+//    }
+
+    /**
+     * Sets the value of the securityRealmName property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+//    public void setSecurityRealmName(String value) {
+//        this.securityRealmName = value;
+//    }
+
+    /**
+     * Gets the value of the authentication property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link AuthenticationType }
+     *     
+     */
+//    public AuthenticationType getAuthentication() {
+//        return authentication;
+//    }
+
+    /**
+     * Sets the value of the authentication property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link AuthenticationType }
+     *     
+     */
+    public void setAuthentication(AuthenticationType value) {
+        super.authentication = value;
+    }
+
+    /**
+     * Gets the value of the security property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link SecurityType }
+     *     
+     */
+//    public SecurityType getSecurity() {
+//        return security;
+//    }
+
+    /**
+     * Sets the value of the security property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link SecurityType }
+     *     
+     */
+//    public void setSecurity(SecurityType value) {
+//        this.security = value;
+//    }
+
+    /**
+     * Gets the value of the securityRef property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link SecurityRefType }
+     *     
+     */
+//    public SecurityRefType getSecurityRef() {
+//        return securityRef;
+//    }
+
+    /**
+     * Sets the value of the securityRef property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link SecurityRefType }
+     *     
+     */
+//    public void setSecurityRef(SecurityRefType value) {
+//        this.securityRef = value;
+//    }
+
+    /**
+     * Gets the value of the any property.
+     * 
+     * <p>
+     * This accessor method returns a reference to the live list,
+     * not a snapshot. Therefore any modification you make to the
+     * returned list will be present inside the JAXB object.
+     * This is why there is not a <CODE>set</CODE> method for the any property.
+     * 
+     * <p>
+     * For example, to add a new item, do as follows:
+     * <pre>
+     *    getAny().add(newItem);
+     * </pre>
+     * 
+     * 
+     * <p>
+     * Objects of the following type(s) are allowed in the list
+     * {@link Object }
+     * 
+     * 
+     */
+    public List<Object> getAny() {
+        if (any == null) {
+            any = new ArrayList<Object>();
+        }
+        return this.any;
+    }
+
+}

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatWebAppType.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatWebAppType.java
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatWebAppType.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Copied: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/package-info.java (from r1098802, geronimo/server/branches/3.0-osgi/plugins/j2ee/geronimo-security-builder/src/main/java/org/apache/geronimo/security/deployment/model/jaspi/package-info.java)
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/package-info.java?p2=geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/package-info.java&p1=geronimo/server/branches/3.0-osgi/plugins/j2ee/geronimo-security-builder/src/main/java/org/apache/geronimo/security/deployment/model/jaspi/package-info.java&r1=1098802&r2=1098803&rev=1098803&view=diff
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/j2ee/geronimo-security-builder/src/main/java/org/apache/geronimo/security/deployment/model/jaspi/package-info.java (original)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/package-info.java Mon May  2 21:49:44 2011
@@ -1,9 +1,9 @@
 //
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.1-833 
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.1-2 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.04.26 at 10:41:22 AM PDT 
+// Generated on: 2011.04.29 at 10:50:34 AM PDT 
 //
 
-@javax.xml.bind.annotation.XmlSchema(namespace = "http://geronimo.apache.org/xml/ns/geronimo-jaspi", elementFormDefault = javax.xml.bind.annotation.XmlNsForm.QUALIFIED)
-package org.apache.geronimo.security.deployment.model.jaspi;
+@javax.xml.bind.annotation.XmlSchema(namespace = "http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1", elementFormDefault = javax.xml.bind.annotation.XmlNsForm.QUALIFIED)
+package org.apache.geronimo.tomcat.deployment.model;

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/package-info.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/package-info.java
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/package-info.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/META-INF/sun-jaxb.episode
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/META-INF/sun-jaxb.episode?rev=1098803&view=auto
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/META-INF/sun-jaxb.episode (added)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/META-INF/sun-jaxb.episode Mon May  2 21:49:44 2011
@@ -0,0 +1,39 @@
+<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
+<bindings version="2.1" xmlns="http://java.sun.com/xml/ns/jaxb">
+  <!--
+
+This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.1-2 
+See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
+Any modifications to this file will be lost upon recompilation of the source schema. 
+Generated on: 2011.04.29 at 10:50:34 AM PDT 
+
+  -->
+  <bindings scd="x-schema::tns" xmlns:tns="http://geronimo.apache.org/xml/ns/web/tomcat/config-1.0">
+    <schemaBindings map="false"/>
+    <bindings scd="~tns:tomcat-configType">
+      <class ref="org.apache.geronimo.tocat.deployment.model.TomcatConfigType"/>
+    </bindings>
+    <bindings scd="~tns:emptyType2">
+      <class ref="org.apache.geronimo.tocat.deployment.model.EmptyType2"/>
+    </bindings>
+  </bindings>
+  <bindings scd="x-schema::tns" xmlns:tns="http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1">
+    <schemaBindings map="false"/>
+    <bindings scd="~tns:emptyType">
+      <class ref="org.apache.geronimo.tocat.deployment.model.EmptyType"/>
+    </bindings>
+    <bindings scd="~tns:parameterType">
+      <class ref="org.apache.geronimo.tocat.deployment.model.ParameterType"/>
+    </bindings>
+    <bindings scd="~tns:contextType">
+      <class ref="org.apache.geronimo.tocat.deployment.model.ContextType"/>
+    </bindings>
+    <bindings scd="~tns:authenticationType">
+      <class ref="org.apache.geronimo.tocat.deployment.model.AuthenticationType"/>
+    </bindings>
+    <bindings scd="~tns:web-appType">
+      <class ref="org.apache.geronimo.tocat.deployment.model.WebAppType"/>
+    </bindings>
+  </bindings>
+</bindings>
+

Added: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/catalog.cat
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/catalog.cat?rev=1098803&view=auto
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/catalog.cat (added)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/catalog.cat Mon May  2 21:49:44 2011
@@ -0,0 +1,17 @@
+PUBLIC "http://geronimo.apache.org/xml/ns/deployment-1.2" "classpath:geronimo-module-1.2.xsd"
+
+PUBLIC "http://geronimo.apache.org/xml/ns/naming-1.2" "classpath:geronimo-naming-1.2.xsd"
+--
+PUBLIC "http://geronimo.apache.org/xml/ns/j2ee/application-2.0" "classpath:geronimo-application-2.0.xsd"
+--
+PUBLIC "http://geronimo.apache.org/xml/ns/geronimo-jaspi" "classpath:geronimo-jaspi.xsd"
+
+PUBLIC "http://geronimo.apache.org/xml/ns/credentialstore-1.0" "classpath:geronimo-credential-store-1.0.xsd"
+
+PUBLIC "http://geronimo.apache.org/xml/ns/loginconfig-2.0" "classpath:geronimo-login-config-2.0.xsd"
+
+PUBLIC "http://geronimo.apache.org/xml/ns/security-2.0" "classpath:geronimo-security-2.0.xsd"
+
+PUBLIC "http://geronimo.apache.org/xml/ns/subject-info-1.0" "classpath:geronimo-subject-info.1.0.xsd"
+
+

Copied: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-2.0.1.xsd (from r1098802, geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/xsd/geronimo-tomcat-2.0.1.xsd)
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-2.0.1.xsd?p2=geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-2.0.1.xsd&p1=geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/xsd/geronimo-tomcat-2.0.1.xsd&r1=1098802&r2=1098803&rev=1098803&view=diff
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/xsd/geronimo-tomcat-2.0.1.xsd (original)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-2.0.1.xsd Mon May  2 21:49:44 2011
@@ -21,8 +21,8 @@
 <xs:schema xmlns:tomcat="http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1"
     targetNamespace="http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1"
     xmlns:naming="http://geronimo.apache.org/xml/ns/naming-1.2"
-    xmlns:app="http://geronimo.apache.org/xml/ns/j2ee/application-2.0"
     xmlns:sys="http://geronimo.apache.org/xml/ns/deployment-1.2"
+    xmlns:sec="http://geronimo.apache.org/xml/ns/security-2.0"
     xmlns:jaspi="http://geronimo.apache.org/xml/ns/geronimo-jaspi"
     xmlns:xs="http://www.w3.org/2001/XMLSchema" elementFormDefault="qualified"
     attributeFormDefault="unqualified" version="1.1">
@@ -44,8 +44,7 @@
         </xs:documentation>
     </xs:annotation>
 
-    <xs:import namespace="http://geronimo.apache.org/xml/ns/naming-1.2"
-        schemaLocation="geronimo-naming-1.2.xsd">
+    <xs:import namespace="http://geronimo.apache.org/xml/ns/naming-1.2">
         <xs:annotation>
             <xs:documentation>
                 Import partial schema containing common naming elements, the
@@ -55,19 +54,17 @@
             </xs:documentation>
         </xs:annotation>
     </xs:import>
-    <xs:import
-        namespace="http://geronimo.apache.org/xml/ns/j2ee/application-2.0"
-        schemaLocation="geronimo-application-2.0.xsd">
-        <xs:annotation>
-            <xs:documentation>
-                Import Geronimo application deployment plans. The imported plan
-                includes abstract complex types security required by this plan
-                schema.
-            </xs:documentation>
-        </xs:annotation>
-    </xs:import>
-    <xs:import namespace="http://geronimo.apache.org/xml/ns/deployment-1.2"
-        schemaLocation="geronimo-module-1.2.xsd">
+    <!--<xs:import-->
+        <!--namespace="http://geronimo.apache.org/xml/ns/j2ee/application-2.0">-->
+        <!--<xs:annotation>-->
+            <!--<xs:documentation>-->
+                <!--Import Geronimo application deployment plans. The imported plan-->
+                <!--includes abstract complex types security required by this plan-->
+                <!--schema.-->
+            <!--</xs:documentation>-->
+        <!--</xs:annotation>-->
+    <!--</xs:import>-->
+    <xs:import namespace="http://geronimo.apache.org/xml/ns/deployment-1.2">
         <xs:annotation>
             <xs:documentation>
                 Import Geronimo Services deployment plans. The imported plan
@@ -77,8 +74,13 @@
         </xs:annotation>
     </xs:import>
 
-    <xs:import namespace="http://geronimo.apache.org/xml/ns/geronimo-jaspi" schemaLocation="geronimo-jaspi.xsd"/>
-  
+    <xs:import namespace="http://geronimo.apache.org/xml/ns/geronimo-jaspi"/>
+    <!-- these might not be used -->
+    <xs:import namespace="http://geronimo.apache.org/xml/ns/credentialstore-1.0"/>
+    <xs:import namespace="http://geronimo.apache.org/xml/ns/loginconfig-2.0"/>
+    <xs:import namespace="http://geronimo.apache.org/xml/ns/security-2.0"/>
+    <xs:import namespace="http://geronimo.apache.org/xml/ns/subject-info-1.0"/>
+
     <xs:element name="web-app" type="tomcat:web-appType">
         <xs:annotation>
             <xs:documentation>
@@ -127,22 +129,22 @@
                 </xs:annotation>
             </xs:element>
 
-            <xs:element ref="app:clustering" minOccurs="0">
-                <xs:annotation>
-                    <xs:documentation>
-                        Reference to abstract clustering element defined in
-                        imported "geronimo-application-2.0.xsd"
-                    </xs:documentation>
-                </xs:annotation>
-            </xs:element>
+            <!--<xs:element ref="app:clustering" minOccurs="0">-->
+                <!--<xs:annotation>-->
+                    <!--<xs:documentation>-->
+                        <!--Reference to abstract clustering element defined in-->
+                        <!--imported "geronimo-application-2.0.xsd"-->
+                    <!--</xs:documentation>-->
+                <!--</xs:annotation>-->
+            <!--</xs:element>-->
 
             <!--<xs:element name="context-priority-classloader" type="xs:boolean" minOccurs="0"/>-->
 
-            <xs:element ref="naming:web-container" minOccurs="0">
+            <xs:element name="web-container" type="xs:string" minOccurs="0">
                 <xs:annotation>
                     <xs:documentation>
-                        Reference to web-container element defined in imported
-                        "geronimo-naming-1.2.xsd"
+                        osgi filter to select the web container service to deploy to, should there be more than one.
+                        TODO may not be needed due to isolation?
                     </xs:documentation>
                 </xs:annotation>
             </xs:element>
@@ -265,27 +267,25 @@
                         </xs:documentation>
                     </xs:annotation>
                 </xs:element>
-                <xs:element ref="app:security" minOccurs="0">
-                    <xs:annotation>
-                        <xs:documentation>
-                            Reference to security element defined in imported
-                            "geronimo-security-2.0.xsd"
-                        </xs:documentation>
-                    </xs:annotation>
-                </xs:element>
+                <xs:choice minOccurs="0">
+                <xs:element ref="sec:security"/>
+                <xs:element ref="sec:security-ref"/>
+                </xs:choice>
             </xs:sequence>
 
-            <xs:choice minOccurs="0" maxOccurs="unbounded">
-                <xs:element ref="sys:service">
-                    <xs:annotation>
-                        <xs:documentation>
-                            Reference to abstract service element defined in imported
-                            "geronimo-module-1.2.xsd"
-                        </xs:documentation>
-                    </xs:annotation>
-                </xs:element>
-                <xs:any namespace="http://java.sun.com/xml/ns/persistence"/>
-            </xs:choice>
+            <xs:any namespace="http://java.sun.com/xml/ns/persistence" minOccurs="0" maxOccurs="unbounded"/>
+
+            <!--<xs:choice minOccurs="0" maxOccurs="unbounded">-->
+                <!--<xs:element ref="sys:service">-->
+                    <!--<xs:annotation>-->
+                        <!--<xs:documentation>-->
+                            <!--Reference to abstract service element defined in imported-->
+                            <!--"geronimo-module-1.2.xsd"-->
+                        <!--</xs:documentation>-->
+                    <!--</xs:annotation>-->
+                <!--</xs:element>-->
+                <!--<xs:any namespace="http://java.sun.com/xml/ns/persistence"/>-->
+            <!--</xs:choice>-->
         </xs:sequence>
     </xs:complexType>
 

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-2.0.1.xsd
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-2.0.1.xsd
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-2.0.1.xsd
------------------------------------------------------------------------------
    svn:mime-type = text/xml

Copied: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-config-1.0.xsd (from r1098802, geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/xsd/geronimo-tomcat-config-1.0.xsd)
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-config-1.0.xsd?p2=geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-config-1.0.xsd&p1=geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/xsd/geronimo-tomcat-config-1.0.xsd&r1=1098802&r2=1098803&rev=1098803&view=diff
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/xsd/geronimo-tomcat-config-1.0.xsd (original)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-config-1.0.xsd Mon May  2 21:49:44 2011
@@ -56,7 +56,7 @@
                     </xs:documentation>
                 </xs:annotation>
             </xs:element>
-            <xs:element name="cross-context" type="tomcat:emptyType"
+            <xs:element name="cross-context" type="tomcat:emptyType2"
                 minOccurs="0">
                 <xs:annotation>
                     <xs:documentation>
@@ -67,7 +67,7 @@
                     </xs:documentation>
                 </xs:annotation>
             </xs:element>
-            <xs:element name="disable-cookies" type="tomcat:emptyType"
+            <xs:element name="disable-cookies" type="tomcat:emptyType2"
                 minOccurs="0">
                 <xs:annotation>
                     <xs:documentation>
@@ -77,6 +77,15 @@
                     </xs:documentation>
                 </xs:annotation>
             </xs:element>
+            <xs:element name="context" type="tomcat:contextType" minOccurs="0">
+                <xs:annotation>
+                    <xs:documentation>
+                        The context element provides the same function as used in
+                        Tomcat, it supports context level attributes and context
+                        parameters.
+                    </xs:documentation>
+                </xs:annotation>
+            </xs:element>
             <xs:element name="valve-chain" type="xs:string" minOccurs="0">
                 <xs:annotation>
                     <xs:documentation>
@@ -120,6 +129,19 @@
         </xs:sequence>
     </xs:complexType>
 
-    <xs:complexType name="emptyType" />
+    <xs:complexType name="contextType">
+        <xs:sequence>
+            <xs:element name="parameter" type="tomcat:parameterType" minOccurs="0" maxOccurs="unbounded"/>
+        </xs:sequence>
+        <xs:anyAttribute processContents="skip"/>
+    </xs:complexType>
+
+    <xs:complexType name="parameterType">
+        <xs:attribute name="name" type="xs:string" />
+        <xs:attribute name="value" type="xs:string" />
+        <xs:attribute name="override" type="xs:boolean" default="false"/>
+    </xs:complexType>
+
+    <xs:complexType name="emptyType2" />
 
 </xs:schema>

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-config-1.0.xsd
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-config-1.0.xsd
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/resources/geronimo-tomcat-config-1.0.xsd
------------------------------------------------------------------------------
    svn:mime-type = text/xml

Modified: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/test/java/org/apache/geronimo/tomcat/deployment/MockResourceEnvironmentSetter.java
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/test/java/org/apache/geronimo/tomcat/deployment/MockResourceEnvironmentSetter.java?rev=1098803&r1=1098802&r2=1098803&view=diff
==============================================================================
--- geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/test/java/org/apache/geronimo/tomcat/deployment/MockResourceEnvironmentSetter.java (original)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/test/java/org/apache/geronimo/tomcat/deployment/MockResourceEnvironmentSetter.java Mon May  2 21:49:44 2011
@@ -18,15 +18,15 @@ package org.apache.geronimo.tomcat.deplo
 
 import java.util.Collection;
 
+import org.apache.geronimo.j2ee.deployment.model.naming.ResourceRefType;
 import org.apache.geronimo.naming.deployment.ResourceEnvironmentBuilder;
 import org.apache.geronimo.naming.deployment.ResourceEnvironmentSetter;
-import org.apache.geronimo.xbeans.geronimo.naming.GerResourceRefType;
 import org.apache.openejb.jee.ResourceRef;
 
 /**
  * @version $Rev$ $Date$
  */
 public class MockResourceEnvironmentSetter implements ResourceEnvironmentSetter {
-    public void setResourceEnvironment(ResourceEnvironmentBuilder builder, Collection<ResourceRef> resourceRefs, GerResourceRefType[] gerResourceRefs) {
+    public void setResourceEnvironment(ResourceEnvironmentBuilder builder, Collection<ResourceRef> resourceRefs, Collection<ResourceRefType> gerResourceRefs) {
     }
 }
--- geronimo/server/branches/3.0-osgi/plugins/j2ee/geronimo-web-2.5-builder/src/main/java/org/apache/geronimo/web25/deployment/model/ObjectFactory.java (original)
+++ geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatObjectFactory.java Mon May  2 21:49:44 2011
@@ -2,23 +2,23 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.1-2 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.04.27 at 07:52:24 PM PDT 
+// Generated on: 2011.04.29 at 10:50:34 AM PDT 
 //
 
 
-package org.apache.geronimo.web25.deployment.model;
+package org.apache.geronimo.tomcat.deployment.model;
 
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.annotation.XmlElementDecl;
 import javax.xml.bind.annotation.XmlRegistry;
 import javax.xml.namespace.QName;
+import org.apache.geronimo.components.jaspi.model.AuthModuleType;
+import org.apache.geronimo.components.jaspi.model.ConfigProviderType;
+import org.apache.geronimo.components.jaspi.model.ServerAuthConfigType;
+import org.apache.geronimo.components.jaspi.model.ServerAuthContextType;
 import org.apache.geronimo.deployment.service.plan.EnvironmentType;
 import org.apache.geronimo.j2ee.deployment.model.naming.AbstractNamingEntryType;
 import org.apache.geronimo.j2ee.deployment.model.naming.MessageDestinationType;
-import org.apache.geronimo.security.deployment.model.jaspi.AuthModuleType;
-import org.apache.geronimo.security.deployment.model.jaspi.ConfigProviderType;
-import org.apache.geronimo.security.deployment.model.jaspi.ServerAuthConfigType;
-import org.apache.geronimo.security.deployment.model.jaspi.ServerAuthContextType;
 import org.apache.geronimo.security.deployment.model.security.SecurityRefType;
 import org.apache.geronimo.security.deployment.model.security.SecurityType;
 
@@ -26,8 +26,8 @@ import org.apache.geronimo.security.depl
 /**
  * This object contains factory methods for each 
  * Java content interface and Java element interface 
  * generated in the org.apache.geronimo.web25.deployment.model package. 
  * <p>An ObjectFactory allows you to programatically 
  * construct new instances of the Java representation 
  * for XML content. The Java representation of XML 
  * content can consist of schema derived interfaces 
@@ -38,40 +38,65 @@ import org.apache.geronimo.security.depl
  * 
  */
 @XmlRegistry
-public class ObjectFactory {
+public class TomcatObjectFactory {
 
     private final static QName _ServerAuthModule_QNAME = new QName("http://geronimo.apache.org/xml/ns/geronimo-jaspi", "serverAuthModule");
     private final static QName _ServerAuthContext_QNAME = new QName("http://geronimo.apache.org/xml/ns/geronimo-jaspi", "serverAuthContext");
     private final static QName _ConfigProvider_QNAME = new QName("http://geronimo.apache.org/xml/ns/geronimo-jaspi", "configProvider");
     private final static QName _ServerAuthConfig_QNAME = new QName("http://geronimo.apache.org/xml/ns/geronimo-jaspi", "serverAuthConfig");
+    public final static QName _Tomcat_QNAME = new QName("http://geronimo.apache.org/xml/ns/web/tomcat/config-1.0", "tomcat");
     private final static QName _MessageDestination_QNAME = new QName("http://geronimo.apache.org/xml/ns/naming-1.2", "message-destination");
-    private final static QName _WebApp_QNAME = new QName("http://geronimo.apache.org/xml/ns/j2ee/web-2.0.1", "web-app");
     private final static QName _Security_QNAME = new QName("http://geronimo.apache.org/xml/ns/security-2.0", "security");
     private final static QName _AbstractNamingEntry_QNAME = new QName("http://geronimo.apache.org/xml/ns/naming-1.2", "abstract-naming-entry");
     private final static QName _Environment_QNAME = new QName("http://geronimo.apache.org/xml/ns/deployment-1.2", "environment");
+    private final static QName _WebApp_QNAME = new QName("http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1", "web-app");
     private final static QName _SecurityRef_QNAME = new QName("http://geronimo.apache.org/xml/ns/security-2.0", "security-ref");
 
     /**
      * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.geronimo.web25.deployment.model
      * 
      */
-    public ObjectFactory() {
+    public TomcatObjectFactory() {
     }
 
     /**
-     * Create an instance of {@link WebAppType }
+     * Create an instance of {@link EmptyType }
      * 
      */
-    public WebAppType createWebAppType() {
-        return new WebAppType();
+    public EmptyType createEmptyType() {
+        return new EmptyType();
     }
 
     /**
-     * Create an instance of {@link ContainerConfigType }
+     * Create an instance of {@link ParameterType }
      * 
      */
-    public ContainerConfigType createContainerConfigType() {
-        return new ContainerConfigType();
+    public ParameterType createParameterType() {
+        return new ParameterType();
+    }
+
+    /**
+     * Create an instance of {@link TomcatConfigType }
+     * 
+     */
+    public TomcatConfigType createTomcatConfigType() {
+        return new TomcatConfigType();
+    }
+
+    /**
+     * Create an instance of {@link EmptyType2 }
+     * 
+     */
+    public EmptyType2 createEmptyType2() {
+        return new EmptyType2();
+    }
+
+    /**
+     * Create an instance of {@link ContextType }
+     * 
+     */
+    public ContextType createContextType() {
+        return new ContextType();
     }
 
     /**
@@ -83,6 +108,14 @@ public class ObjectFactory {
     }
 
     /**
+     * Create an instance of {@link TomcatWebAppType }
+     * 
+     */
+    public TomcatWebAppType createWebAppType() {
+        return new TomcatWebAppType();
+    }
+
+    /**
      * Create an instance of {@link JAXBElement }{@code <}{@link AuthModuleType }{@code >}}
      * 
      */
@@ -119,21 +152,21 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link MessageDestinationType }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link TomcatConfigType }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://geronimo.apache.org/xml/ns/naming-1.2", name = "message-destination")
-    public JAXBElement<MessageDestinationType> createMessageDestination(MessageDestinationType value) {
-        return new JAXBElement<MessageDestinationType>(_MessageDestination_QNAME, MessageDestinationType.class, null, value);
+    @XmlElementDecl(namespace = "http://geronimo.apache.org/xml/ns/web/tomcat/config-1.0", name = "tomcat")
+    public JAXBElement<TomcatConfigType> createTomcat(TomcatConfigType value) {
+        return new JAXBElement<TomcatConfigType>(_Tomcat_QNAME, TomcatConfigType.class, null, value);
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link WebAppType }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link MessageDestinationType }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://geronimo.apache.org/xml/ns/j2ee/web-2.0.1", name = "web-app")
-    public JAXBElement<WebAppType> createWebApp(WebAppType value) {
-        return new JAXBElement<WebAppType>(_WebApp_QNAME, WebAppType.class, null, value);
+    @XmlElementDecl(namespace = "http://geronimo.apache.org/xml/ns/naming-1.2", name = "message-destination")
+    public JAXBElement<MessageDestinationType> createMessageDestination(MessageDestinationType value) {
+        return new JAXBElement<MessageDestinationType>(_MessageDestination_QNAME, MessageDestinationType.class, null, value);
     }
 
     /**
@@ -164,6 +197,15 @@ public class ObjectFactory {
     }
 
     /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link TomcatWebAppType }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://geronimo.apache.org/xml/ns/j2ee/web/tomcat-2.0.1", name = "web-app")
+    public JAXBElement<TomcatWebAppType> createWebApp(TomcatWebAppType value) {
+        return new JAXBElement<TomcatWebAppType>(_WebApp_QNAME, TomcatWebAppType.class, null, value);
+    }
+
+    /**
      * Create an instance of {@link JAXBElement }{@code <}{@link SecurityRefType }{@code >}}
      * 
      */
@@ -26,8 +26,8 @@ import org.apache.geronimo.security.depl
  * This object contains factory methods for each 
  * Java content interface and Java element interface 
- * generated in the org.apache.geronimo.web25.deployment.model package. 
- * <p>An ObjectFactory allows you to programatically 
+ * generated in the org.apache.geronimo.tocat.deployment.model package. 
+ * <p>An TomcatObjectFactory allows you to programatically
  * construct new instances of the Java representation 
  * for XML content. The Java representation of XML 
@@ -38,40 +38,65 @@ import org.apache.geronimo.security.depl
 
     /**
-     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.geronimo.web25.deployment.model
+     * Create a new TomcatObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.geronimo.tocat.deployment.model
      * 
      */

Added: geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatWebAppType.java
URL: http://svn.apache.org/viewvc/geronimo/server/branches/3.0-osgi/plugins/tomcat/geronimo-tomcat7-builder/src/main/java/org/apache/geronimo/tomcat/deployment/model/TomcatWebAppType.java?rev=1098803&view=auto
==============================================================================